@@ -1,7 +1,4 @@
 """
-Connectors
-----------
-
 Connectors provide a way to access document (files or otherwise) from a source, and they form the starting point
 for Pipelines
 """
